@@ -314,7 +314,7 @@ class PercentTrue(AggregationPrimitive):
 
             def chunk(s):
                 def format_chunk(x):
-                    return x[:].fillna(0)
+                    return x[:].fillna(False)
 
                 chunk_sum = s.agg(lambda x: format_chunk(x).sum())
                 chunk_len = s.agg(lambda x: len(format_chunk(x)))
@@ -333,7 +333,7 @@ class PercentTrue(AggregationPrimitive):
             return dd.Aggregation(self.name, chunk=chunk, agg=agg, finalize=finalize)
 
         def percent_true(s):
-            return s.fillna(0).mean()
+            return s.fillna(False).mean()
 
         return percent_true
 
