@@ -3,6 +3,8 @@ from featuretools.primitives.standard.aggregation_primitives import *
 from featuretools.primitives.standard.binary_transform import *
 from featuretools.primitives.standard.cum_transform_feature import *
 from featuretools.primitives.standard.datetime_transform_primitives import *
+from featuretools.primitives.standard.exponential_transform_primitives import *
 from featuretools.primitives.standard.latlong_transform_primitives import *
-from featuretools.primitives.standard.rolling_transform_primitive import *
+from featuretools.primitives.standard.natural_language_primitives.api import *
+from featuretools.primitives.standard.rolling_transform_primitives import *
 from featuretools.primitives.standard.transform_primitive import *
