@@ -109,11 +109,11 @@ def test_init_and_name(es):
 
     trans_primitives = get_transform_primitives().values()
     # If Dask EntitySet use only Dask compatible primitives
-    if es.dataframe_type == Library.DASK.value:
+    if es.dataframe_type == Library.DASK:
         trans_primitives = [
             prim for prim in trans_primitives if Library.DASK in prim.compatibility
         ]
-    if es.dataframe_type == Library.SPARK.value:
+    if es.dataframe_type == Library.SPARK:
         trans_primitives = [
             prim for prim in trans_primitives if Library.SPARK in prim.compatibility
         ]
@@ -276,7 +276,7 @@ def test_equal_categorical(simple_es):
     )
 
     df = calculate_feature_matrix(entityset=simple_es, features=[f1])
-    if simple_es.dataframe_type != Library.SPARK.value:
+    if simple_es.dataframe_type != Library.SPARK:
         # Spark does not support categorical dtype
         assert set(simple_es["values"]["value"].cat.categories) != set(
             simple_es["values"]["value2"].cat.categories,
@@ -327,7 +327,7 @@ def test_not_equal_categorical(simple_es):
 
     df = calculate_feature_matrix(entityset=simple_es, features=[f1])
 
-    if simple_es.dataframe_type != Library.SPARK.value:
+    if simple_es.dataframe_type != Library.SPARK:
         # Spark does not support categorical dtype
         assert set(simple_es["values"]["value"].cat.categories) != set(
             simple_es["values"]["value2"].cat.categories,
@@ -624,7 +624,7 @@ def test_compare_of_agg(es):
 
 
 def test_compare_all_nans(es):
-    if es.dataframe_type != Library.PANDAS.value:
+    if es.dataframe_type != Library.PANDAS:
         nan_feat = Feature(
             es["log"].ww["value"],
             parent_dataframe_name="sessions",
@@ -701,7 +701,7 @@ def test_arithmetic_of_identity(es):
         (DivideNumeric, [np.nan, 2.5, 2.5, 2.5]),
     ]
     # SubtractNumeric not supported for Spark EntitySets
-    if es.dataframe_type == Library.SPARK.value:
+    if es.dataframe_type == Library.SPARK:
         to_test = to_test[:1] + to_test[2:]
 
     features = []
@@ -745,7 +745,7 @@ def test_arithmetic_of_direct(es):
         (MultiplyNumeric, [165, 132, 148.5, 148.5]),
         (DivideNumeric, [6.6, 8.25, 22.0 / 3, 22.0 / 3]),
     ]
-    if es.dataframe_type == Library.SPARK.value:
+    if es.dataframe_type == Library.SPARK:
         to_test = to_test[:1] + to_test[2:]
 
     features = []
@@ -831,7 +831,7 @@ def test_boolean_multiply(boolean_mult_es):
 
 # TODO: rework test to be Dask and Spark compatible
 def test_arithmetic_of_transform(es):
-    if es.dataframe_type != Library.PANDAS.value:
+    if es.dataframe_type != Library.PANDAS:
         pytest.xfail("Test uses Diff which is not supported in Dask or Spark")
     diff1 = Feature([Feature(es["log"].ww["value"])], primitive=Diff)
     diff2 = Feature([Feature(es["log"].ww["value_2"])], primitive=Diff)
@@ -888,7 +888,7 @@ def test_arithmetic_of_agg(es):
         (DivideNumeric, [1, 0]),
     ]
     # Skip SubtractNumeric for Spark as it's unsupported
-    if es.dataframe_type == Library.SPARK.value:
+    if es.dataframe_type == Library.SPARK:
         to_test = to_test[:1] + to_test[2:]
 
     features = []
@@ -1530,7 +1530,7 @@ def test_override_multi_feature_names(pd_es):
 
 
 def test_time_since_primitive_matches_all_datetime_types(es):
-    if es.dataframe_type == Library.SPARK.value:
+    if es.dataframe_type == Library.SPARK:
         pytest.xfail("TimeSince transform primitive is incompatible with Spark")
     fm, fl = dfs(
         target_dataframe_name="customers",
@@ -1687,7 +1687,7 @@ def test_cfm_with_lag_and_non_nullable_columns(pd_es):
 
 
 def test_comparisons_with_ordinal_valid_inputs(es):
-    if es.dataframe_type == Library.SPARK.value:
+    if es.dataframe_type == Library.SPARK:
         pytest.xfail(
             "Categorical dtypes not used in Spark, and comparison works as expected without error.",
         )
@@ -1725,7 +1725,7 @@ def test_comparisons_with_ordinal_valid_inputs(es):
 
 
 def test_comparisons_with_ordinal_invalid_inputs(es):
-    if es.dataframe_type == Library.SPARK.value:
+    if es.dataframe_type == Library.SPARK:
         pytest.xfail(
             "Categorical dtypes not used in Spark, and comparison works as expected without error.",
         )
